#
# spec file for package perl-Task-Kensho-Config
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Task-Kensho-Config
Name:           perl-Task-Kensho-Config
Version:        0.41
Release:        bp154.1.17
Summary:        Glimpse at an Enlightened Perl: Config Modules
License:        Artistic-1.0 OR GPL-1.0-or-later
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/E/ET/ETHER/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Config::Any)
BuildRequires:  perl(Config::General)
BuildRequires:  perl(JSON::MaybeXS)
Requires:       perl(Config::Any)
Requires:       perl(Config::General)
Requires:       perl(JSON::MaybeXS)
%{perl_requires}

%description
From http://en.wikipedia.org/wiki/Kensho:

    Kenshō (見性) (C. Wu) is a Japanese term for enlightenment experiences -
    most commonly used within the confines of Zen Buddhism - literally
    meaning "seeing one's nature"[1] or "true self."[2] It generally
    "refers to the realization of nonduality of subject and object."[3]

Task::Kensho is a list of recommended modules for Enlightened Perl
development. CPAN is wonderful, but there are too many wheels and you have
to pick and choose amongst the various competing technologies.

The plan is for Task::Kensho to be a rough testing ground for ideas that go
into among other things the Enlightened Perl Organisation Extended Core
(EPO-EC).

The modules that are bundled by Task::Kensho are broken down into several
categories and are still being considered. They are all taken from various
top 100 most used perl modules lists and from discussions with various
subject matter experts in the Perl Community. That said, this bundle does
_not_ follow the guidelines established for the EPO-EC for peer review via
industry advisers.

Starting in 2011, Task::Kensho split its sub-groups of modules into
individually-installable tasks. Each Task::Kensho sub-task is listed at the
beginning of its section in this documentation.

When installing Task::Kensho itself, you will be asked to install each
sub-task in turn, or you can install individual tasks separately. These
individual tasks will always install all their modules by default. This
facilitates the ease and simplicity the distribution aims to achieve.

%prep
%autosetup  -n %{cpan_name}-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README
%license LICENCE

%changelog
* Sun Jul  4 2021 Tina Müller <timueller+perl@suse.de>
- updated to 0.41
  see /usr/share/doc/packages/perl-Task-Kensho-Config/Changes
  0.41      2021-07-03
  - Async: added Future, Mojo::IOLoop, MCE, Parallel::ForkManager
  - Dates: added Time::Piece; removed Date::Tiny, Time::Tiny, DateTime::Tiny
  - ExcelCSV: replaced Spreadsheet::ParseExcel with Spreadsheet::Read,
    added Excel::Writer::XLSX
  - Hackery: added ojo
  - Logging: added Log::Any
  - Testing: added Test2::Suite
  - WebCrawling: added Mojo::UserAgent
  - WebDev: added Web::Simple
* Thu Dec  6 2018 Stephan Kulow <coolo@suse.com>
- updated to 0.40
  see /usr/share/doc/packages/perl-Task-Kensho-Config/Changes
  0.40      2018-12-01
  - CLI: added Reply
  - Dates: added Time::Moment
  - Email: added Email::Stuffer
  - Exceptions: added Syntax::Keyword::Try
  - ModuleDev: added Code::TidyAll, removed Perl::Version
  - OOP: removed Task::Moose
  - Toolchain: added App::cpm
  - WebDev: added HTTP::BrowserDetect, Attean
  - XML: removed RDF::Trine
* Mon May 23 2016 coolo@suse.com
- updated to 0.39
  see /usr/share/doc/packages/perl-Task-Kensho-Config/Changes
  0.39      2016-05-14
  - WebDev: removed Dancer, added Dancer2
  - OOP: added Moose, Moo and many related modules
  - Exceptions: remove TryCatch
  - Testing: remove Test::Most and Test::NoWarnings, added Test::Warnings
  - Config: added JSON::MaybeXS
* Fri Sep 19 2014 coolo@suse.com
- updated to 0.38
  - WebDev: Template::Toolkit is not indexed (see RT#92588) -
    refer to Template instead
  - subtask distributions now just use regular prereqs on their
    component modules, rather than using optional_features metadata
  - Task-Kensho now once again prompts at install time for each
    subtask to be optionally installed
  0.37      2014-08-16
  - ModuleDev: Switch Carp::Always over to Devel::Confess (per mst)
  - ModuleDev: Add Data::Printer (per Sawyer X)
  - ModuleDev: Add Devel::Dwarn (per mst)
  - Toolchain: Add Pinto (per Sawyer X)
  - Toolchain: Add App::FatPacker (per perigrin)
  0.36      2014-03-08
  - fix pod markup error in main Task::Kensho distribution
  - module list revisions to CLI, Dates, Toolchain, WebCrawling,
    WebDev
* Sun Feb  9 2014 coolo@suse.com
- updated to 0.35
  - updated recommendations for Async, CLI, ModuleDev, Scalability,
    WebDev
  - still more pod and metadata tweaks
  - more pod and metadata tweaks
  - fix mangled abstract in META.*
  - fixed missing list of recommendations in Task::Kensho pod
  - fix munging of ::Hackery preamble into stopwords
  - fixed bugtracker metadata (now indicating github issues)
  - distributions split apart again, with new! and enhanced!
    Dist::Zilla generation magic
  - distributions reunified under Task-Kensho, and now auto-generated
    from a master YAML file using Dist::Zilla
  - Task::Kensho::Testing:
  - Retired Test::Exception and replaced with Test::Fatal
  - added Test::Deep, Test::Requires and Test::NoWarnings
  - Task::Kensho::WebDev: added Plack
  - Fix reference to Module::CoreList (RT#65948)
  - Add Plack to Task::Kensho::WebDev
  - Fix Task::Kensho::Logging version, thanks kent
* Sat Mar 26 2011 coolo@opensuse.org
- initial package 0.28
  * created by cpanspec 1.78.03
* Fri Jan 21 2011 coolo@novell.com
- initial package 0.27
  * created by cpanspec 1.78.03
